Module core

Module core 

Core components of the micro-gui stack

Copyright 2017 Ryan Kurte

Re-exports

pub use self::buffer::Buff;
pub use self::buffer::Buffer;

Modules

buffer
Buffer module creates a read write buffer from a reference to a data array.
layer
window
Window implements the top level GUI abstraction. Windows can create and consume events, and contain a base layer from which windows can be implemented.