Module window

Module window 

Window implements the top level GUI abstraction. Windows can create and consume events, and contain a base layer from which windows can be implemented.

Copyright 2017 Ryan Kurte

Structs

Window
Window object contains renderable layers and handles events

Traits

OnEvent
OnEvent trait called to receive an event
OnLoad
OnLoad trait called when a window is loaded
OnUnload
OnUnload trait called when a window is unloaded