Module graphics

Module graphics 

Graphics module provides underlying rendering functions over a generic buffer This is used by components or widgets for rendering purposes.

Copyright 2017 Ryan Kurte

Structs

Graphics
Graphics context used for rendering components This includes offsets and dimensions to shift rendering scopes

Traits

Renderable
Renderable trait implemented by types that can render themselves For example, widgets should implement the renderable trait to be bound into layers
Sprite
Sprite trait implemented by types that can be rendered from a buffer