pub struct Gui<'a, Pixel> { /* private fields */ }Expand description
Top level Gui object
Implementations
Sourceimpl<'a, Pixel> Gui<'a, Pixel>
impl<'a, Pixel> Gui<'a, Pixel>
Sourcepub fn new(w: usize, h: usize) -> Self
pub fn new(w: usize, h: usize) -> Self
Create a new Gui instance of the provided size with the specified buffer
Sourcepub fn push_window(&mut self, w: &'a mut Window<'a, Pixel>)
pub fn push_window(&mut self, w: &'a mut Window<'a, Pixel>)
Push a window to the top of the window stack This will cause the window to be rendered
Sourcepub fn pop_window(&mut self) -> Option<&mut Window<'a, Pixel>>
pub fn pop_window(&mut self) -> Option<&mut Window<'a, Pixel>>
Pop a window from the top of the window stack This will cause the previous window to be re-rendered