Types module defines types for use across ugui implementation
Copyright 2017 Ryan Kurte
Re-exports
pub use self::pixel::PixelBW;pub use self::pixel::PixelRGB24;pub use self::point::Point;pub use self::rect::Rect;pub use self::events::Event;
Modules
- events
- Events for ugui interaction
- pixel
- Pixel type definitions This is designed so that modules that do not need to interact with pixels directly can use pixel::Pixel or standard pixel traits and be compatible with all pixel representations.
- point
- Point represents a point in 2d space
- rect
- Types module defines types for use across ugui implementation