Module pixel

Module pixel 

Pixel type definitions This is designed so that modules that do not need to interact with pixels directly can use pixel::Pixel or standard pixel traits and be compatible with all pixel representations.

Copyright 2017 Ryan Kurte

Structs

PixelG8
8-bit grey-scale pixel implementation
PixelRGB24
24-bit RGB pixel implementation

Traits

BW
Black and White trait to be implemented by all colours
RGB
RGB trait to be implemented by all colours

Type Aliases

PixelBW
1-bit wlack and white pixel implementation