Buffer module creates a read write buffer from a reference to a data array.
Copyright 2017 Ryan Kurte
Structs
- Buffer
- Buffer implements a generic display buffer over an arbitrary pixel type
Traits
- Buff
- Buff trait encompasses methods required for a graphics buffer