Graphics

Struct Graphics 

pub struct Graphics<Pixel> { /* private fields */ }
Graphics context used for rendering components This includes offsets and dimensions to shift rendering scopes

Implementations

Source

impl<Pixel> Graphics<Pixel>

pub fn new(x: usize, y: usize, w: usize, h: usize) -> Self

New creates a new graphcs context with the provided offsets and limits

pub fn set(&self, b: &mut dyn Buff<Pixel>, x: usize, y: usize, p: &Pixel)

Set wraps a buffer in a graphics context to shift rendering functions

pub fn get_bounds(&mut self) -> Rect

pub fn set_bounds(&mut self, bounds: &Rect)

Set new bounds for rendering This will offset and limit rendering by the provided values.

pub fn draw_line( &self, buf: &mut dyn Buff<Pixel>, p1: Point, p2: Point, p: &Pixel, )

Draws a line between two points with the provided pixel style

pub fn draw_rect(&self, b: &mut dyn Buff<Pixel>, r: Rect, p: &Pixel)

Draws a rectange with the provided pixel style

pub fn fill_rect(&self, b: &mut dyn Buff<Pixel>, r: Rect, p: &Pixel)

Draws a rectangle with the provided pixel style

pub fn draw_polyline( &self, b: &mut dyn Buff<Pixel>, points: &[Point], p: &Pixel, )

Draws a polyline connecting a list of points

pub fn draw_ellipse(&self, buf: &mut dyn Buff<Pixel>, r: Rect, p: &Pixel)

Draws an ellipse to fill the provided rectangle